@@ -36,65 +36,64 @@
 
 #include "indic-ot.h"
 
-enum
-{
-    /*
-     * Split matra table indices
-     */
-    _x1 = 1 << CF_INDEX_SHIFT,
-    _x2 = 2 << CF_INDEX_SHIFT,
-    _x3 = 3 << CF_INDEX_SHIFT,
-    _x4 = 4 << CF_INDEX_SHIFT,
-    _x5 = 5 << CF_INDEX_SHIFT,
-    _x6 = 6 << CF_INDEX_SHIFT,
-    _x7 = 7 << CF_INDEX_SHIFT,
-    _x8 = 8 << CF_INDEX_SHIFT,
-    _x9 = 9 << CF_INDEX_SHIFT,
 
-    /*
-     * Simple classes
-     */
-    _xx = CC_RESERVED,
-    _ma = CC_MODIFYING_MARK_ABOVE,
-    _mp = CC_MODIFYING_MARK_POST,
-    _iv = CC_INDEPENDENT_VOWEL,
-    _ct = CC_CONSONANT | CF_CONSONANT,
-    _cn = CC_CONSONANT_WITH_NUKTA | CF_CONSONANT,
-    _nu = CC_NUKTA,
-    _dv = CC_DEPENDENT_VOWEL,
-    _dl = _dv | CF_MATRA_PRE,
-    _db = _dv | CF_MATRA_BELOW,
-    _da = _dv | CF_MATRA_ABOVE,
-    _dr = _dv | CF_MATRA_POST,
-    _lm = _dv | CF_LENGTH_MARK,
-    _vr = CC_VIRAMA,
-    _al = CC_AL_LAKUNA,
+/*
+ * Split matra table indices
+ */
+#define _x1 (1 << CF_INDEX_SHIFT)
+#define _x2 (2 << CF_INDEX_SHIFT)
+#define _x3 (3 << CF_INDEX_SHIFT)
+#define _x4 (4 << CF_INDEX_SHIFT)
+#define _x5 (5 << CF_INDEX_SHIFT)
+#define _x6 (6 << CF_INDEX_SHIFT)
+#define _x7 (7 << CF_INDEX_SHIFT)
+#define _x8 (8 << CF_INDEX_SHIFT)
+#define _x9 (9 << CF_INDEX_SHIFT)
 
-    /*
-     * Split matras
-     */
-    _s1 = _dv | _x1,
-    _s2 = _dv | _x2,
-    _s3 = _dv | _x3,
-    _s4 = _dv | _x4,
-    _s5 = _dv | _x5,
-    _s6 = _dv | _x6,
-    _s7 = _dv | _x7,
-    _s8 = _dv | _x8,
-    _s9 = _dv | _x9,
+/*
+ * Simple classes
+ */
+#define _xx (CC_RESERVED)
+#define _ma (CC_MODIFYING_MARK_ABOVE)
+#define _mp (CC_MODIFYING_MARK_POST)
+#define _iv (CC_INDEPENDENT_VOWEL)
+#define _ct (CC_CONSONANT | CF_CONSONANT)
+#define _cn (CC_CONSONANT_WITH_NUKTA | CF_CONSONANT)
+#define _nu (CC_NUKTA)
+#define _dv (CC_DEPENDENT_VOWEL)
+#define _dl (_dv | CF_MATRA_PRE)
+#define _db (_dv | CF_MATRA_BELOW)
+#define _da (_dv | CF_MATRA_ABOVE)
+#define _dr (_dv | CF_MATRA_POST)
+#define _lm (_dv | CF_LENGTH_MARK)
+#define _vr (CC_VIRAMA)
+#define _al (CC_AL_LAKUNA)
+
+/*
+ * Split matras
+ */
+#define _s1 (_dv | _x1)
+#define _s2 (_dv | _x2)
+#define _s3 (_dv | _x3)
+#define _s4 (_dv | _x4)
+#define _s5 (_dv | _x5)
+#define _s6 (_dv | _x6)
+#define _s7 (_dv | _x7)
+#define _s8 (_dv | _x8)
+#define _s9 (_dv | _x9)
+
+/*
+ * consonants with special forms
+ * NOTE: this assumes that no consonants with nukta have
+ * special forms... (Bengali RA?)
+ */
+#define _bb (_ct | CF_BELOW_BASE)
+#define _pb (_ct | CF_POST_BASE)
+#define _vt (_bb | CF_VATTU)
+#define _rv (_vt | CF_REPH)
+#define _rp (_pb | CF_REPH)
+#define _rb (_bb | CF_REPH)
 
-    /*
-     * consonants with special forms
-     * NOTE: this assumes that no consonants with nukta have
-     * special forms... (Bengali RA?)
-     */
-    _bb = _ct | CF_BELOW_BASE,
-    _pb = _ct | CF_POST_BASE,
-    _vt = _bb | CF_VATTU,
-    _rv = _vt | CF_REPH,
-    _rp = _pb | CF_REPH,
-    _rb = _bb | CF_REPH
-};
 
 /*
  * Character class tables
@@ -469,48 +468,6 @@ glong indic_ot_find_syllable(const IndicOTClassTable *class_table, const gunicha
 
         state = stateTable[state][char_class & CF_CLASS_MASK];
 
-        /*for the components of split matra*/	
-	if ((char_count >= cursor + 3) &&
-	    (chars[cursor] == 0x0DD9 && chars[cursor + 1] == 0x0DCF && chars[cursor + 2] == 0x0DCA)) {  /*for 3 split matra of Sinhala*/
-	    return cursor + 3;
-	}        
-	else if ((char_count >= cursor + 3) &&
-	         (chars[cursor] == 0x0CC6 && chars[cursor + 1] == 0x0CC2 && chars[cursor + 2] == 0x0CD5)) {  /*for 3 split matra of Kannada*/
-	    return cursor + 3;
-	}
-        /*for 2 split matra*/	
-	else if (char_count >= cursor + 2) {
-	        /*for Bengali*/
-            if ((chars[cursor] == 0x09C7 && chars[cursor + 1] == 0x09BE) ||	       
-	        (chars[cursor] == 0x09C7 && chars[cursor + 1] == 0x09D7) ||		
-	        /*for Oriya*/
-	        (chars[cursor] == 0x0B47 && chars[cursor + 1] == 0x0B3E) ||		
-	        (chars[cursor] == 0x0B47 && chars[cursor + 1] == 0x0B56) ||		
-	        (chars[cursor] == 0x0B47 && chars[cursor + 1] == 0x0B57) ||
-	        /*for Tamil*/
-	        (chars[cursor] == 0x0BC6 && chars[cursor + 1] == 0x0BBE) ||		
-	        (chars[cursor] == 0x0BC6 && chars[cursor + 1] == 0x0BD7) ||		
-	        (chars[cursor] == 0x0BC7 && chars[cursor + 1] == 0x0BBE) ||		
-	        /*for Malayalam*/
-	        (chars[cursor] == 0x0D46 && chars[cursor + 1] == 0x0D3E) ||	
-	        (chars[cursor] == 0x0D46 && chars[cursor + 1] == 0x0D57) ||		
-	        (chars[cursor] == 0x0D47 && chars[cursor + 1] == 0x0D3E) ||	
-	        /*for Sinhala*/
-	        (chars[cursor] == 0x0DD9 && chars[cursor + 1] == 0x0DCA) ||		
-	        (chars[cursor] == 0x0DD9 && chars[cursor + 1] == 0x0DCF) ||		
-	        (chars[cursor] == 0x0DD9 && chars[cursor + 1] == 0x0DDF) ||		
-	        (chars[cursor] == 0x0DDC && chars[cursor + 1] == 0x0DCA) ||		
-	        /*for Telugu*/
-	        (chars[cursor] == 0x0C46 && chars[cursor + 1] == 0x0C56) ||	
-	        /*for Kannada*/
-	        (chars[cursor] == 0x0CBF && chars[cursor + 1] == 0x0CD5) ||		    
-	        (chars[cursor] == 0x0CC6 && chars[cursor + 1] == 0x0CD5) ||		
-	        (chars[cursor] == 0x0CC6 && chars[cursor + 1] == 0x0CD6) ||		
-	        (chars[cursor] == 0x0CC6 && chars[cursor + 1] == 0x0CC2) ||		
-	        (chars[cursor] == 0x0CCA && chars[cursor + 1] == 0x0CD5))
-		    return cursor + 2;
-	}
-
         if (state < 0) {
             break;
         }
