@@ -36,6 +36,9 @@ struct _PangoContext
 
   PangoLanguage *language;
   PangoDirection base_dir;
+  PangoGravity base_gravity;
+  PangoGravity resolved_gravity;
+
   PangoFontDescription *font_desc;
 
   PangoMatrix *matrix;
@@ -57,6 +60,7 @@ static void
 pango_context_init (PangoContext *context)
 {
   context->base_dir = PANGO_DIRECTION_WEAK_LTR;
+  context->resolved_gravity = context->base_gravity = PANGO_GRAVITY_SOUTH;
   context->language = NULL;
   context->font_map = NULL;
 
@@ -103,8 +107,8 @@ pango_context_finalize (GObject *object)
  * This function is only useful when implementing a new backend
  * for Pango, something applications won't do. You should use
  * the context creation function for the backend you are using,
- * for example, pango_cairo_font_map_create_context(), pango_xft_get_context(),
- * pango_win32_get_context() or, pango_ft2_font_map_create_context().
+ * for example, pango_xft_get_context(), pango_win32_get_context()
+ * or, pango_ft2_font_map_create_context().
  *
  * If you are using Pango as part of a higher-level system,
  * that system may have it's own ways of create a #PangoContext.
@@ -125,6 +129,15 @@ pango_context_new (void)
   return context;
 }
 
+static void
+update_resolved_gravity (PangoContext *context)
+{
+  if (context->base_gravity == PANGO_GRAVITY_AUTO)
+    context->resolved_gravity = pango_matrix_to_gravity (context->matrix);
+  else
+    context->resolved_gravity = context->base_gravity;
+}
+
 /**
  * pango_context_set_matrix:
  * @context: a #PangoContext
@@ -134,7 +147,7 @@ pango_context_new (void)
  * Sets the transformation matrix that will be applied when rendering
  * with this context. Note that reported metrics are in the user space
  * coordinates before the application of the matrix, not device-space
- * coordinates after the application of the matrix. So, they don't scale
+ * coordiantes after the application of the matrix. So, they don't scale
  * with the matrix, though they may change slightly for different
  * matrices, depending on how the text is fit to the pixel grid.
  *
@@ -152,6 +165,8 @@ pango_context_set_matrix (PangoContext       *context,
     context->matrix = pango_matrix_copy (matrix);
   else
     context->matrix = NULL;
+
+  update_resolved_gravity (context);
 }
 
 /**
@@ -223,7 +238,7 @@ pango_context_get_font_map (PangoContext *context)
 /**
  * pango_context_list_families:
  * @context: a #PangoContext
- * @families: location to store a pointer to an array of #PangoFontFamily *.
+ * @families: location to store a pointer to an array of PangoFontFamily *.
  *            This array should be freed with g_free().
  * @n_families: location to store the number of elements in @descs
  * 
@@ -402,6 +417,68 @@ pango_context_get_base_dir (PangoContext *context)
   return context->base_dir;
 }
 
+/**
+ * pango_context_set_base_gravity:
+ * @context: a #PangoContext
+ * @gravity: the new base gravity
+ * 
+ * Sets the base gravity for the context.
+ *
+ * The base gravity is used in laying vertical text out.
+ *
+ * Since: 1.16
+ **/
+void
+pango_context_set_base_gravity (PangoContext  *context,
+				PangoGravity gravity)
+{
+  g_return_if_fail (context != NULL);
+
+  context->base_gravity = gravity;
+
+  update_resolved_gravity (context);
+}
+
+/**
+ * pango_context_get_base_gravity:
+ * @context: a #PangoContext
+ * 
+ * Retrieves the base gravity for the context. See
+ * pango_context_set_base_gravity().
+ * 
+ * Return value: the base gravity for the context.
+ *
+ * Since: 1.16
+ **/
+PangoGravity
+pango_context_get_base_gravity (PangoContext *context)
+{
+  g_return_val_if_fail (context != NULL, PANGO_GRAVITY_SOUTH);
+
+  return context->base_gravity;
+}
+
+/**
+ * pango_context_get_gravity:
+ * @context: a #PangoContext
+ * 
+ * Retrieves the gravity for the context. This is similar to
+ * pango_context_get_base_gravity(), except for when the base gravity
+ * is %PANGO_GRAVITY_AUTO for which pango_matrix_to_gravity() is used
+ * to return the gravity from the current context matrix.
+ * 
+ * Return value: the resolved gravity for the context.
+ *
+ * Since: 1.16
+ **/
+PangoGravity
+pango_context_get_gravity (PangoContext *context)
+{
+  g_return_val_if_fail (context != NULL, PANGO_GRAVITY_SOUTH);
+
+  return context->resolved_gravity;
+}
+
 /**********************************************************************/
 
 static gboolean
@@ -539,6 +616,10 @@ struct _ItemizeState
   const char *embedding_end;
   guint8 embedding;
 
+  PangoGravity gravity;
+  PangoGravity font_desc_gravity;
+  gboolean centered_baseline;
+
   PangoAttrIterator *attr_iter;
   gboolean free_attr_iter;
   const char *attr_end;
@@ -611,6 +692,11 @@ update_attr_iterator (ItemizeState *state)
   state->font_desc = pango_font_description_copy_static (state->context->font_desc);
   pango_attr_iterator_get_font (state->attr_iter, state->font_desc,
 				&state->lang, &state->extra_attrs);
+  if (pango_font_description_get_set_fields (state->font_desc) & PANGO_FONT_MASK_GRAVITY)
+    state->font_desc_gravity = pango_font_description_get_gravity (state->font_desc);
+  else
+    state->font_desc_gravity = PANGO_GRAVITY_AUTO;
+
   state->copy_extra_attrs = FALSE;
 
   if (!state->lang)
@@ -663,7 +749,7 @@ itemize_state_init (ItemizeState      *state,
   state->embedding_end_offset = 0;
   state->embedding_end = text + start_index;
   update_embedding_end (state);
-  
+
   /* Initialize the attribute iterator
    */
   if (cached_iter)
@@ -709,6 +795,15 @@ itemize_state_init (ItemizeState      *state,
 
   update_end (state);
 
+  state->centered_baseline = state->context->resolved_gravity == PANGO_GRAVITY_EAST
+			  || state->context->resolved_gravity == PANGO_GRAVITY_WEST;
+
+  if (pango_font_description_get_set_fields (state->font_desc) & PANGO_FONT_MASK_GRAVITY)
+    state->font_desc_gravity = pango_font_description_get_gravity (state->font_desc);
+  else
+    state->font_desc_gravity = PANGO_GRAVITY_AUTO;
+
+  state->gravity = PANGO_GRAVITY_AUTO;
   state->derived_lang = NULL;
   state->lang_engine = NULL;
   state->current_fonts = NULL;
@@ -829,6 +924,41 @@ itemize_state_add_character (ItemizeState     *state,
   state->item->analysis.font = font;
   
   state->item->analysis.level = state->embedding;
+  state->item->analysis.gravity = state->gravity;
+
+  /* The level vs. gravity dance:
+   * 	- If gravity is SOUTH, leave level untouched.
+   * 	- If gravity is NORTH, step level one up, to
+   * 	  not get mirrored upside-down text.
+   * 	- If gravity is EAST, step up to an even level, as
+   * 	  it's a clockwise-rotated layout, so the rotated
+   * 	  top is unrotated left.
+   * 	- If gravity is WEST, step up to an odd level, as
+   * 	  it's a counter-clockwise-rotated layout, so the rotated
+   * 	  top is unrotated right.
+   *
+   * A similar dance is performed in pango-layout.c:
+   * line_set_resolved_dir().  Keep in synch.
+   */
+  switch (state->item->analysis.gravity)
+    {
+      case PANGO_GRAVITY_SOUTH:
+      default:
+	break;
+      case PANGO_GRAVITY_NORTH:
+	state->item->analysis.level++;
+	break;
+      case PANGO_GRAVITY_EAST:
+	state->item->analysis.level += 1;
+	state->item->analysis.level &= ~1;
+	break;
+      case PANGO_GRAVITY_WEST:
+	state->item->analysis.level |= 1;
+	break;
+    }
+
+  state->item->analysis.centered_baseline = state->centered_baseline;
+
   state->item->analysis.language = state->derived_lang;
   
   if (state->copy_extra_attrs)
@@ -917,8 +1047,29 @@ get_shaper_and_font (ItemizeState      *state,
     return *shape_engine != NULL;
 
   if (!state->exact_engines && !state->fallback_engines)
-    get_engines (state->context, state->derived_lang, state->script,
-		 &state->exact_engines, &state->fallback_engines);
+    {
+      /* Always use a basic shaper for vertical layout (ie, east/west gravity)
+       * as we do not support vertical shaping as of now.
+       */
+      PangoScript script;
+
+      switch (state->gravity)
+	{
+	  case PANGO_GRAVITY_SOUTH:
+	  case PANGO_GRAVITY_NORTH:
+	  case PANGO_GRAVITY_AUTO:
+	  default:
+            script = state->script;
+	    break;
+	  case PANGO_GRAVITY_EAST:
+	  case PANGO_GRAVITY_WEST:
+            script = PANGO_SCRIPT_COMMON;
+	    break;
+	}
+
+      get_engines (state->context, state->derived_lang, script,
+		   &state->exact_engines, &state->fallback_engines);
+    }
 
   info.lang = state->derived_lang;
   info.wc = wc;
@@ -1015,6 +1166,30 @@ get_lang_map (PangoLanguage *lang)
 static void
 itemize_state_update_for_new_run (ItemizeState *state)
 {
+  if (state->changed & (FONT_CHANGED | SCRIPT_CHANGED))
+    {
+      PangoGravity old_gravity = state->gravity;
+
+      if (state->font_desc_gravity != PANGO_GRAVITY_AUTO)
+	state->gravity = state->font_desc_gravity;
+      else
+        {
+	  PangoGravity gravity = state->context->resolved_gravity;
+
+	  /* FIXME
+	   * gravity = pango_script_get_resolved_gravity (script, gravity, hint);
+	   */
+
+	  state->gravity = gravity;
+	}
+
+      if (old_gravity != state->gravity)
+        {
+	  pango_font_description_set_gravity (state->font_desc, state->gravity);
+          state->changed |= FONT_CHANGED;
+	}
+    }
+
   if (state->changed & (SCRIPT_CHANGED | LANG_CHANGED))
     {
       PangoLanguage *old_derived_lang = state->derived_lang;
@@ -1091,24 +1266,23 @@ itemize_state_process_run (ItemizeState *state)
        * emulated ideographic space for the primary font wouldn't be the
        * right size.
        *
-       * The exception of PrivateUse and Unassigned characters is necessary
-       * to be able to render any of them. (for private or being encoded
-       * scripts, etc.)
+       * The exception of PrivateUse characters is indeed necessary to be
+       * able to render any of them.
        */
       /*
       if (G_UNLIKELY (!g_unichar_isgraph (wc) && wc != 0x3000 &&
-		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
-		      g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
+		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE))
 	*/
       if (G_UNLIKELY (!g_unichar_isprint (wc) &&
-		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
-		      g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
+		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE))
 	{
 	  shape_engine = NULL;
 	  font = NULL;
 	}
       else
-        get_shaper_and_font (state, wc, &shape_engine, &font);
+        {
+	  get_shaper_and_font (state, wc, &shape_engine, &font);
+	}
 	
       itemize_state_add_character (state,
 				   shape_engine, font,
@@ -1167,9 +1341,9 @@ itemize_state_finish (ItemizeState *state)
  *
  * Like pango_itemize(), but the base direction to use when
  * computing bidirectional levels (see pango_context_set_base_dir ()),
- * is specified explicitly rather than gotten from the #PangoContext.
+ * is specified explicitely rather than gotten from the #PangoContext.
  *
- * Return value: a #GList of #PangoItem structures.
+ * Return value: a GList of PangoItem structures.
  *
  * Since: 1.4
  */
@@ -1251,7 +1425,7 @@ itemize_with_font (PangoContext               *context,
  * the range covering the position just after @start_index + @length.
  * (i.e. if itemizing in a loop, just keep passing in the same @cached_iter).
  *
- * Return value: a #GList of #PangoItem structures.
+ * Return value: a GList of PangoItem structures.
  */
 GList *
 pango_itemize (PangoContext      *context, 
@@ -1358,7 +1532,7 @@ update_metrics_from_items (PangoFontMetrics *metrics,
  * @desc: a #PangoFontDescription structure
  * @language: language tag used to determine which script to get the metrics
  *            for. %NULL means that the language tag from the context will
- *            be used. If no language tag is set on the context, metrics
+ *            be used. If no language tag is set on the ccontext, metrics
  *            large enough to cover a range of languages will be returned.
  *            The process of determining such metrics is slow, so it is best
  *            to always make sure some real language tag will be used.
