@@ -101,7 +101,11 @@ struct _PangoEngineLang
 /**
  * PangoEngineLangClass:
  * @script_break: Provides a custom implementation of pango_break().
- *  if this is %NULL, pango_default_break() will be used.
+ * If %NULL, pango_default_break() is used instead. If not %NULL, for
+ * Pango versions before 1.16 (module interface version before 1.6.0),
+ * this was called instead of pango_default_break(), but in newer versions,
+ * pango_default_break() is always called and this is called after that to
+ * allow tailoring the breaking results.
  *
  * Class structure for #PangoEngineLang
  **/
@@ -141,7 +145,7 @@ typedef struct _PangoEngineShapeClass PangoEngineShapeClass;
  * A #PangoEngineShape implementation is then specific to both
  * a particular rendering system or group of rendering systems
  * and to a particular script. For instance, there is one
- * #PangoEngineShape implementation to handling shaping Arabic
+ * #PangoEngineShape implementation to handle shaping Arabic
  * for Fontconfig-based backends.
  **/
 struct _PangoEngineShape
@@ -270,7 +274,7 @@ static GType prefix ## _type;						  \
 static void								  \
 prefix ## _register_type (GTypeModule *module)				  \
 {									  \
-  static const GTypeInfo object_info =					  \
+  const GTypeInfo object_info =						  \
     {									  \
       sizeof (name ## Class),						  \
       (GBaseInitFunc) NULL,						  \
