@@ -75,7 +75,7 @@ struct _PangoLayoutLine
   gint         length;		/* length of line in bytes */
   GSList      *runs;
   guint        is_paragraph_start : 1;  /* TRUE if this is the first line of the paragraph */ 
-  guint        resolved_dir : 3;  /* Resolved direction of line */
+  guint        resolved_dir : 3;  /* Resolved PangoDirection of line */
 };
 
 #define PANGO_TYPE_LAYOUT              (pango_layout_get_type ())
@@ -116,6 +116,9 @@ void           pango_layout_set_markup_with_accel (PangoLayout    *layout,
 
 void           pango_layout_set_font_description (PangoLayout                *layout,
 						  const PangoFontDescription *desc);
+
+G_CONST_RETURN PangoFontDescription *pango_layout_get_font_description (PangoLayout *layout);
+
 void           pango_layout_set_width            (PangoLayout                *layout,
 						  int                         width);
 int            pango_layout_get_width            (PangoLayout                *layout);
@@ -160,6 +163,11 @@ void     pango_layout_get_log_attrs (PangoLayout    *layout,
 void     pango_layout_index_to_pos         (PangoLayout    *layout,
 					    int             index_,
 					    PangoRectangle *pos);
+void     pango_layout_index_to_line_x      (PangoLayout    *layout,
+			                    int             index_,
+			                    gboolean        trailing,
+			                    int            *line,
+			                    int            *x_pos);
 void     pango_layout_get_cursor_pos       (PangoLayout    *layout,
 					    int             index_,
 					    PangoRectangle *strong_pos,
@@ -194,8 +202,13 @@ PangoLayoutLine *pango_layout_get_line             (PangoLayout    *layout,
 						    int             line);
 GSList *         pango_layout_get_lines            (PangoLayout    *layout);
 
-void     pango_layout_line_ref          (PangoLayoutLine  *line);
-void     pango_layout_line_unref        (PangoLayoutLine  *line);
+#define PANGO_TYPE_LAYOUT_LINE (pango_layout_line_get_type ())
+
+GType    pango_layout_line_get_type     (void) G_GNUC_CONST;
+
+PangoLayoutLine *pango_layout_line_ref   (PangoLayoutLine *line);
+void             pango_layout_line_unref (PangoLayoutLine *line);
+
 gboolean pango_layout_line_x_to_index   (PangoLayoutLine  *line,
 					 int               x_pos,
 					 int              *index_,
