@@ -200,7 +200,7 @@ pango_atsui_family_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (PangoFontFamilyClass),
         (GBaseInitFunc) NULL,
@@ -319,7 +319,7 @@ pango_atsui_face_get_type (void)
 
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (PangoFontFaceClass),
         (GBaseInitFunc) NULL,
@@ -578,6 +578,9 @@ pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
 	    }
 	}
       
+      if (best_desc == NULL || best_face == NULL)
+        return NULL;
+
       pango_font_description_set_size (best_desc, size);
 
       best_font = pango_atsui_font_map_lookup (atsuifontmap, context, best_desc, best_face->postscript_name);
