@@ -161,7 +161,7 @@ pango_ft2_font_render_glyph (PangoFont *font,
 
   if (glyph_index & PANGO_GLYPH_UNKNOWN_FLAG)
     {
-      static PangoFT2RenderedGlyph *box;
+      PangoFT2RenderedGlyph *box;
       PangoFontMetrics *metrics;
 
       if (!font)
@@ -171,9 +171,6 @@ pango_ft2_font_render_glyph (PangoFont *font,
       if (!metrics)
 	goto generic_box;
 
-      /* this box gets cached, so don't bother with static'ing it.
-       */
-
       box = pango_ft2_font_render_box_glyph (PANGO_PIXELS (metrics->approximate_char_width),
 					     PANGO_PIXELS (metrics->ascent + metrics->descent),
 					     PANGO_PIXELS (metrics->ascent));
@@ -207,17 +204,10 @@ pango_ft2_font_render_glyph (PangoFont *font,
     }
   else
     {
-      static PangoFT2RenderedGlyph *box = NULL;
-
-    generic_box:
-      if (!box)
-        {
-	  box = pango_ft2_font_render_box_glyph (PANGO_UNKNOWN_GLYPH_WIDTH,
-						 PANGO_UNKNOWN_GLYPH_HEIGHT,
-						 PANGO_UNKNOWN_GLYPH_HEIGHT);
-	}
-
-      return box;
+generic_box:
+      return  pango_ft2_font_render_box_glyph (PANGO_UNKNOWN_GLYPH_WIDTH,
+					       PANGO_UNKNOWN_GLYPH_HEIGHT,
+					       PANGO_UNKNOWN_GLYPH_HEIGHT);
     }
 }
 
@@ -546,7 +536,7 @@ pango_ft2_renderer_draw_trapezoid (PangoRenderer   *renderer,
 
 /**
  * pango_ft2_render_layout_subpixel:
- * @bitmap:    a <type>FT_Bitmap</type> to render the layout onto
+ * @bitmap:    a FT_Bitmap to render the layout onto
  * @layout:    a #PangoLayout
  * @x:         the X position of the left of the layout (in Pango units)
  * @y:         the Y position of the top of the layout (in Pango units)
@@ -583,7 +573,7 @@ pango_ft2_render_layout_subpixel (FT_Bitmap   *bitmap,
 
 /**
  * pango_ft2_render_layout:
- * @bitmap:    a <type>FT_Bitmap</type> to render the layout onto
+ * @bitmap:    a FT_Bitmap to render the layout onto
  * @layout:    a #PangoLayout
  * @x:         the X position of the left of the layout (in pixels)
  * @y:         the Y position of the top of the layout (in pixels)
@@ -601,7 +591,7 @@ pango_ft2_render_layout (FT_Bitmap   *bitmap,
 
 /**
  * pango_ft2_render_layout_line_subpixel:
- * @bitmap:    a <type>FT_Bitmap</type> to render the line onto
+ * @bitmap:    a FT_Bitmap to render the line onto
  * @line:      a #PangoLayoutLine
  * @x:         the x position of start of string (in Pango units)
  * @y:         the y position of baseline (in Pango units)
@@ -638,7 +628,7 @@ pango_ft2_render_layout_line_subpixel (FT_Bitmap       *bitmap,
 
 /**
  * pango_ft2_render_layout_line:
- * @bitmap:    a <type>FT_Bitmap</type> to render the line onto
+ * @bitmap:    a FT_Bitmap to render the line onto
  * @line:      a #PangoLayoutLine
  * @x:         the x position of start of string (in pixels)
  * @y:         the y position of baseline (in pixels)
